@@ -16,6 +16,8 @@ from polly.bridge_cohort import CohortRepoClass
 from polly.core_cohort import CohortFileStandard
 from polly import constants as const
 from polly.help import example, doc
+from polly.auth import Polly
+from polly.tracking import Track
 
 
 class Cohort:
@@ -46,13 +48,15 @@ merge metadata and data-matrix of samples/datasets in a cohort and edit or delet
         env = helpers.get_platform_value_from_env(
             const.COMPUTE_ENV_VARIABLE, default_env, env
         )
+        self.session = Polly.get_session(token, env=env)
         if self._cohort_info is None:
             self._cohort_info = helpers.get_cohort_constants()
         self._cohort_path = None
         self._cohort_details = None
-        self.bridge_obj = CohortRepoClass(token, env)
+        self.bridge_obj = CohortRepoClass(self.session)
         self.core_obj = CohortFileStandard()
 
+    @Track.track_decorator
     def create_cohort(
         self,
         local_path: str,
@@ -112,6 +116,7 @@ cohort.
                 sample_id=sample_id,
             )
 
+    @Track.track_decorator
     def add_to_cohort(self, repo_key: str, dataset_id=None, sample_id=None) -> None:
         """
         This function is used to add datasets or samples to a cohort.
@@ -167,6 +172,7 @@ instantiated.
             )
         self._cohort_details = self.bridge_obj._cohort_details
 
+    @Track.track_decorator
     def remove_from_cohort(self, dataset_id=None, sample_id=[]) -> None:
         """
         This function is used for removing datasets or samples from a cohort.
@@ -202,6 +208,7 @@ instantiated.
             )
         self._cohort_details = self.core_obj._cohort_details
 
+    @Track.track_decorator
     def merge_data(self, data_level: str):
         """
         Function to merge metadata (dataset, sample and feature level metadata) or data-matrix of all the samples\
